<?php

/**
 * Elementor Team Widget.
 *
 *
 * @since 1.0.0
 */
class Elementor_Section_2Col_Widget extends \Elementor\Widget_Base
{

	/**
	 * Get widget name.
	 *
	 * Retrieve Team widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name()
	{
		return 'section-two-columns';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Team widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title()
	{
		return __('Section 2 Spalten', 'elementor-custom-widgets');
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Team widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon()
	{
		return 'eicon-column';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Team widget belongs to.
	 * Named aqb to be on top of the other categories
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories()
	{
		return ['aqb-widgets'];
	}

	/**
	 * Register widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function _register_controls()
	{

		$this->start_controls_section(
			'content_section',
			[
				'label' => __('Inhalt', 'elementor-custom-widgets'),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'title',
			[
				'label' => __('Titel', 'elementor-custom-widgets'),
				'type' => \Elementor\Controls_Manager::TEXT,
				'placeholder' => __('Lorem Ipsum...', 'elementor-custom-widgets'),
			]
		);

		$this->add_control(
			'font_type',
			[
				'label' => __('Schrifttyp', 'elementor-custom-widgets'),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'p',
				'options' => [
					'h1'  => __('H1', 'elementor-custom-widgets'),
					'h2'  => __('H2', 'elementor-custom-widgets'),
					'h3'  => __('H3', 'elementor-custom-widgets'),
					'h4'  => __('H4', 'elementor-custom-widgets'),
					'big-font'  => __('Große Schrift', 'elementor-custom-widgets'),
					'medium-font'  => __('Mittlere Schrift', 'elementor-custom-widgets'),
					'p'  => __('Normale Schrift', 'elementor-custom-widgets'),
				],
			]
		);

		$this->add_control(
			'font_transform',
			[
				'label' => __( 'Versalien?', 'elementor-custom-widgets' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __( 'Normal', 'elementor-custom-widgets' ),
				'label_off' => __( 'Versalien', 'elementor-custom-widgets' ),
				'return_value' => 'normal',
				'default' => 'normal',
			]
		);

		$this->add_control(
			'section_content',
			[
				'label' => __('Inhaltstext', 'elementor-custom-widgets'),
				'type' => \Elementor\Controls_Manager::WYSIWYG,
				//'default' => __( 'Default description', 'elementor-custom-widgets' ),
				'placeholder' => __('Lorem Ipsum...', 'elementor-custom-widgets'),
			]
		);

		$this->add_control(
			'padding',
			[
				'label' => __( 'Padding', 'plugin-domain' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .section-2col .section-content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'hr-divider',
			[
				'type' => \Elementor\Controls_Manager::DIVIDER,
			]
		);	

		$this->add_control(
			'image',
			[
				'label' => __('Bild wählen', 'elementor-custom-widgets'),
				'type' => \Elementor\Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				]
			]
		);		

		$this->end_controls_section();

		/**
		 * Style section
		 */

		$this->start_controls_section(
			'style_section',
			[
				'label' => __('Style', 'elementor-custom-widgets'),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'column_position',
			[
				'label' => __('Spaltenaufteilung', 'elementor-custom-widgets'),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'fifty-fifty',
				'options' => [
					'full-width'  => __('Volle Breite', 'elementor-custom-widgets'),
					'fifty-fifty'  => __('50/50', 'elementor-custom-widgets'),
					'two-thirds' => __('66/33', 'elementor-custom-widgets'),
					'one-third'  => __('33/66', 'elementor-custom-widgets'),
				],
			]
		);

		$this->add_control(
			'hr-divider2',
			[
				'type' => \Elementor\Controls_Manager::DIVIDER,
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'background',
				'label' => __( 'Background', 'elementor-custom-widgets' ),
				'types' => [ 'classic' ],
				'selector' => '{{WRAPPER}} .section-2col .main-container > div',
			]
		);

		$this->end_controls_section();
	}

	/**
	 * Render widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() 
	{
		$settings = $this->get_settings_for_display();
		
		$settings['font_type'] !== 'big-font' && $settings['font_type'] !== 'medium-font' ? $font_type = $settings['font_type'] : $font_type = 'p';
		$settings['font_type'] == 'big-font' || $settings['font_type'] == 'medium-font' ? $font_class = $settings['font_type'] : $font_class = '';
		$settings['font_transform'] !== 'normal' ? $font_transform = ' uppercase' : $font_transform = '';
		$settings['image']['url'] !== '' ? $content_image = '<div class="section-image" style="background-image:url('.$settings['image']['url'].');"></div>' : $content_image = '';

		echo '<div class="section-2col">';
			echo '<div class="main-container">';
				echo '<div class="' . $settings['column_position'] . '">';
					echo '<div class="section-content"><'.$font_type.' class="'.$font_class.$font_transform.'">' . $settings['title'] . '</'.$font_type.'><p>' . $settings['section_content'] . '</p></div>';
					echo $content_image;
				echo '</div>';
			echo '</div>';
		echo '</div>';
	}
	

	protected function content_template() 
	{
		?>
		<#
			var fontType = settings.font_type !== 'big-font' && settings.font_type !== 'medium-font' ? settings.font_type : 'p';
			var fontClass = settings.font_type == 'big-font' || settings.font_type == 'medium-font' ? settings.font_type : '';
			var fontTransform = settings.font_transform !== 'normal' ? ' uppercase' : '';
			var contentImage = settings.image.url !== '' ? '<div class="section-image" style="background-image:url('+ settings.image.url +');"></div>' : '';
		#>
		<div class="section-2col">
			<div class="main-container">
				<div class="{{{ settings.column_position }}}">
					<div class="section-content"><{{{fontType}}} class="{{{fontClass}}}{{{fontTransform}}}">{{{ settings.title }}}</{{{fontType}}}><p>{{{ settings.section_content }}}</p></div>
					{{{contentImage}}}
				</div>
			</div>
		</div>
		<?php
	}
}