<?php

/**
 * Elementor Team Widget.
 *
 *
 * @since 1.0.0
 */
class Elementor_Section_Background_Widget extends \Elementor\Widget_Base
{

	/**
	 * Get widget name.
	 *
	 * Retrieve Team widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name()
	{
		return 'section-background';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Team widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title()
	{
		return __('Hintergrundbild-/Video', 'elementor-custom-widgets');
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Team widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon()
	{
		return 'eicon-image';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Team widget belongs to.
	 * Named aqb to be on top of the other categories
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories()
	{
		return ['aqb-widgets'];
	}

	/**
	 * Register widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function _register_controls()
	{

		$this->start_controls_section(
			'content_section',
			[
				'label' => __('Inhalt', 'elementor-custom-widgets'),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'background',
				'label' => __( 'Background', 'elementor-custom-widgets' ),
				'types' => [ 'classic', 'video' ],
				'selector' => '{{WRAPPER}} .wrapper',
			]
		);

		$this->end_controls_section();
	}

	/**
	 * Render Team widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();

		$settings['background_color'] !== '' ? $bgColor = 'background-color:'.$settings['background_color'].';' : $bgColor = '';
		!empty($settings['background_image']['url']) ? $bgImage = 'background-image:url('.$settings['background_image']['url'].');' : $bgImage = '';
		$settings['background_position'] !== '' ? $bgPosition = 'background-position:'.$settings['background_position'].';' : $bgPosition = '';
		$settings['background_repeat'] !== '' ? $bgRepeat = 'background-repeat:'.$settings['background_repeat'].';' : $bgRepeat = '';
		$settings['background_size'] !== '' ? $bgSize = 'background-size:'.$settings['background_size'].';' : $bgSize = '';
		$styleContainer = '';

		if ($bgColor !== '' || $bgImage !== '' || $bgPosition !== '' || $bgRepeat !== '' || $bgSize !== '') {
			$styleContainer = '
			<style>
				.section-background .bg-image {
					'.$bgColor.'
					'.$bgImage.'
					'.$bgPosition.'
					'.$bgRepeat.'
					'.$bgSize.'
				} 			
			</style>
			';
		}

		//var_dump($settings);
		echo '<div class="section-background">';
			echo '<div class="main-container">';
				if ($settings['background_background'] == 'video') {
					echo '<video src="' . $settings['background_video_link'] . '" controls>';
				} else {
					echo '<div class="bg-image"></div>';
					echo $styleContainer;
				}	
			echo '</div>';
		echo '</div>';
	}
	

	protected function content_template() {
		?>
		<div class="section-background">
			<div class="main-container">
				<# if ( settings.background_background === 'video' ) { #>
					<video src="{{{ settings.background_video_link }}}" controls>
				<# } else { #>
					<div class="bg-image"></div>
					<style>
						.section-background .bg-image {
							background-color: {{{ settings.background_color }}};
							background-image: url({{{ settings.background_image.url }}});
							background-position: {{{ settings.background_position }}};
							background-repeat: {{{ settings.background_repeat }}};
							background-size: {{{ settings.background_size }}};
						}
					</style>
				<# } #>
			</div>
		</div>
		<?php
	}
}