<?php

/**
 * Elementor Team Widget.
 *
 *
 * @since 1.0.0
 */
class Elementor_Section_Benefits_Widget extends \Elementor\Widget_Base
{

	/**
	 * Get widget name.
	 *
	 * Retrieve Team widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name()
	{
		return 'section-benefits';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Team widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title()
	{
		return __('Section Vorteile', 'elementor-custom-widgets');
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Team widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon()
	{
		return 'eicon-hotspot';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Team widget belongs to.
	 * Named aqb to be on top of the other categories
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories()
	{
		return ['aqb-widgets'];
	}

	/**
	 * Register widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function _register_controls()
	{

		$this->start_controls_section(
			'content_section',
			[
				'label' => __('Inhalt', 'elementor-custom-widgets'),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'section_title',
			[
				'label' => __('Sektionstitel', 'elementor-custom-widgets'),
				'type' => \Elementor\Controls_Manager::TEXT,
				'placeholder' => __('Geben Sie bitte den Titel der Seite ein', 'elementor-custom-widgets'),
			]
		);

		$this->add_control(
			'grid_select',
			[
				'label' => esc_html__( 'Grid wählen', 'elementor-custom-widgets' ),
				'type' => \Elementor\Controls_Manager::CHOOSE,
				'options' => [
					'grid3' => [
						'title' => esc_html__( '3er Grid', 'elementor-custom-widgets' ),
						'icon' => 'eicon-menu-bar',
					],
					'grid4' => [
						'title' => esc_html__( '4er Grid', 'elementor-custom-widgets' ),
						'icon' => 'eicon-text-align-justify',
					],
				],
				'default' => 'grid3',
				'toggle' => false,
			]
		);

		/**
		 * Start repater section
		 */

		$repeater = new \Elementor\Repeater();

		$repeater->add_control(
			'list_title',
			[
				'label' => __('Titel', 'elementor-custom-widgets'),
				'type' => \Elementor\Controls_Manager::TEXT,
				'placeholder' => __('Geben Sie bitte den Titel der Seite ein', 'elementor-custom-widgets'),
			]
		);

		$repeater->add_control(
			'content_image',
			[
				'label' => __('Bild wählen', 'elementor-custom-widgets'),
				'type' => \Elementor\Controls_Manager::MEDIA,
				//'default' => [
				//	'url' => \Elementor\Utils::get_placeholder_image_src(),
				//]
			]
		);

		$repeater->add_control(
			'section_content',
			[
				'label' => __('Inhaltstext', 'elementor-custom-widgets'),
				'type' => \Elementor\Controls_Manager::TEXTAREA,
				//'default' => __( 'Bitte fügen Sie hier den gewünschten Text ein', 'elementor-custom-widgets' ),
				'placeholder' => __('Lorem Ipsum...', 'elementor-custom-widgets'),
			]
		);

		$repeater->add_control(
			'section_link',
			[
				'label' => __('Link', 'elementor-custom-widgets'),
				'type' => \Elementor\Controls_Manager::URL,
				'placeholder' => __( 'https://example.com', 'elementor-custom-widgets' ),
				'show_external' => true,
				'default' => [
					'url' => '',
					'is_external' => false,
					'nofollow' => false,
				],
			]
		);

		$this->add_control(
			'list',
			[
				'label' => __('Liste', 'elementor-custom-widgets'),
				'type' => \Elementor\Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'default' => [
					[
						'list_title' => __('Item #1', 'elementor-custom-widgets'),
						'list_content' => __('Item content. Click the edit button to change this text.', 'elementor-custom-widgets'),
					],
					[
						'list_title' => __('Item #2', 'elementor-custom-widgets'),
						'list_content' => __('Item content. Click the edit button to change this text.', 'elementor-custom-widgets'),
					],
				],
				'title_field' => '{{{ list_title }}}',
			]
		);

		$this->end_controls_section();
	}

	/**
	 * Render Team widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() 
	{
		$settings = $this->get_settings_for_display();
		
		echo '<div class="section-benefits '. $settings['grid_select'].'">';
			echo '<p class="medium-font">' . $settings['section_title'] . '</p>';
			echo '<div class="main-container flex-wrapper">';
				
				foreach ($settings['list'] as $item) 
				{
					$target = $item['section_link']['is_external'] ? ' target="_blank"' : '';
					$nofollow = $item['section_link']['nofollow'] ? ' rel="nofollow"' : '';

					if (!empty($item['section_link']['url'])) {
						echo '<a class="benefit-item" href="' . $item['section_link']['url'] . '" title="' . $item['list_title'] . '"' . $target . $nofollow . '>';
							echo '<div class="benefit-item-inner">';
								echo '<img src="' . $item['content_image']['url'] . '" alt="">';
								echo '<p class="item-title">' . $item['list_title'] . '</p>';								
								echo '<p>' . $item['section_content'] . '</p>';
							echo '</div>';
						echo '</a>';
					} else {
						echo '<div class="benefit-item">';
							echo '<img src="' . $item['content_image']['url'] . '" alt="">';
							echo '<p class="item-title">' . $item['list_title'] . '</p>';								
							echo '<p>' . $item['section_content'] . '</p>';
						echo '</div>';
					}					
				}

			echo '</div>';
		echo '</div>';
	}

	protected function content_template() {
		?>
		<div class="section-benefits {{{settings.grid_select}}}">
			<p class="medium-font">{{{settings.section_title}}}</p>
			<div class="main-container flex-wrapepr">
				<# _.each( settings.list, function( item ) { #>
					<div class="benefit-item">
						<img src="{{item.content_image.url}}" alt="">
						<p class="item-title">{{{item.list_title}}}</p>
						<p>{{{item.section_content}}}</p>
					</div>
				<# }); #>
			</div>
		</div>		
		<?php
	}
}