<?php

/**
 * Elementor Team Widget.
 *
 *
 * @since 1.0.0
 */
class Elementor_Section_Contact_Person_Widget extends \Elementor\Widget_Base
{

	/**
	 * Get widget name.
	 *
	 * Retrieve Team widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name()
	{
		return 'section-contact-person';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Team widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title()
	{
		return __('Kontakt Person', 'elementor-custom-widgets');
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Team widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon()
	{
		return 'eicon-person';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Team widget belongs to.
	 * Named aqb to be on top of the other categories
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories()
	{
		return ['aqb-widgets'];
	}

	/**
	 * Register widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function _register_controls()
	{

		$this->start_controls_section(
			'content_section',
			[
				'label' => __('Inhalt', 'elementor-custom-widgets'),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'content',
			[
				'label' => __('Begleittext', 'elementor-custom-widgets'),
				'type' => \Elementor\Controls_Manager::TEXTAREA,
				'placeholder' => __('Geben Sie bitte den Begleittext ein', 'elementor-custom-widgets'),
			]
		);

		$this->add_control(
			'prename',
			[
				'label' => __('Vorname', 'elementor-custom-widgets'),
				'type' => \Elementor\Controls_Manager::TEXT,
				'placeholder' => __('Geben Sie den Vornamen ein', 'elementor-custom-widgets'),
			]
		);

		$this->add_control(
			'lastname',
			[
				'label' => __('Nachname', 'elementor-custom-widgets'),
				'type' => \Elementor\Controls_Manager::TEXT,
				'placeholder' => __('Geben Sie den Nachnamen ein', 'elementor-custom-widgets'),
			]
		);

		$this->add_control(
			'phone',
			[
				'label' => __('Telefonnummer', 'elementor-custom-widgets'),
				'type' => \Elementor\Controls_Manager::TEXT,
				'placeholder' => __('Geben Sie bitte die Telefonnummer ein', 'elementor-custom-widgets'),
			]
		);

		$this->add_control(
			'mail',
			[
				'label' => __('Email', 'elementor-custom-widgets'),
				'type' => \Elementor\Controls_Manager::TEXT,
				'placeholder' => __('Geben Sie die Emailadresse ein', 'elementor-custom-widgets'),
			]
		);

		$this->end_controls_section();
	}

	/**
	 * Render Team widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		
		echo '<div class="main-container">';
			echo '<div class="section-contact-person">';
				echo '<div class="section-content"><p class="medium-font">' . $settings['content'] . '</p></div>';
				echo '<div class="section-contact">';
					echo '<p>' . $settings['prename'] . ' ' . $settings['lastname']. '</p>';
					echo '<p>' . $settings['phone'] . '<br>' . $settings['mail'] . '</p>';
				echo '</div>';
			echo '</div>';
		echo '</div>';
	}
	

	protected function content_template() {
		?>
		<div class="main-container">
			<div class="section-contact-person">
				<div class="section-content"><p class="medium-font">{{{settings.content}}}</p></div>
					<div class="section-contact">
						<p>{{{settings.prename}}} {{{settings.lastname}}}</p>
						<p>{{{settings.phone}}}<br>{{{settings.mail}}}</p>
					</div>
				</div>
			</div>
		</div>
		<?php
	}
}