<?php

/**
 * Elementor Team Widget.
 *
 *
 * @since 1.0.0
 */
class Elementor_Section_Gallery_Slider_Intro_Widget extends \Elementor\Widget_Base
{

	/**
	 * Get widget name.
	 *
	 * Retrieve Team widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name()
	{
		return 'section-gallery-slider';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Team widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title()
	{
		return __('Gallery Slider', 'elementor-custom-widgets');
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Team widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon()
	{
		return 'eicon-slider-album';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Team widget belongs to.
	 * Named aqb to be on top of the other categories
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories()
	{
		return ['aqb-widgets'];
	}

	/**
	 * Register widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function _register_controls()
	{

		$this->start_controls_section(
			'content_section',
			[
				'label' => __('Inhalt', 'elementor-custom-widgets'),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'title',
			[
				'label' => __('Titel', 'elementor-custom-widgets'),
				'type' => \Elementor\Controls_Manager::TEXT,
				'placeholder' => __('Lorem Ipsum...', 'elementor-custom-widgets'),
			]
		);

		$this->add_control(
			'gallery',
			[
				'label' => __( 'Bild hinzufügen', 'elementor-custom-widgets' ),
				'type' => \Elementor\Controls_Manager::GALLERY,
				'default' => [],
			]
		);

		$this->end_controls_section();
	}

	/**
	 * Render Team widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() 
	{
		$settings = $this->get_settings_for_display();
		$widget_id = $this->get_data()['id'];

		// Use the widget id to make a clear distinction between the individual sliders
		$init_script = "var swiper_" . $widget_id . " = new Swiper('.swiper-container.widget_id_" . $widget_id . "', {
			loop: true,
		
			navigation: {
				nextEl: '.widget_id_" . $widget_id  . " .swiper-button-next',
				prevEl: '.widget_id_" . $widget_id  . " .swiper-button-prev',
			},

			slidesPerView: 1,
			spaceBetween: 15,
			// Responsive breakpoints
			breakpoints: {
				// when window width is >= 320px
				480: {
					slidesPerView: 2,
					spaceBetween: 20
				},
				// when window width is >= 480px
				768: {
					slidesPerView: 3,
					spaceBetween: 30
				}
			}
		});";
		
		echo '<div class="section-gallery-slider widget_id_' . $widget_id . '">';
			echo '<div class="slider-control-wrapper main-container'.(!empty($settings['title']) ? ' with-title' : '').'">';
				if(!empty($settings['title'])) {
					echo '<div class="inner-title medium-font">' . $settings['title'] . '</div>';
				}				
				echo '<div class="swiper-button-prev"></div>';
				echo '<div class="swiper-button-next"></div>';
			echo '</div>';
			echo '<div class="swiper-container main-container widget_id_' . $widget_id . '">';	
				echo '<div class="swiper-wrapper">';

					foreach ($settings['gallery'] as $image) 
					{
						echo '<div class="swiper-slide">';
							echo '<img src="' . $image['url'] . '" alt="">';
						echo '</div>';
					}

				echo '</div>';
			echo '</div>';
		echo '</div>';

		/**
		 * Check if the user is in live edit mode or not
		 * If not in live edit, load the js on doc ready otherwiese load it immediately
		 * Inline init script is used in case multiple sliders are on one page
		 */
		if( \Elementor\Plugin::$instance->editor->is_edit_mode() ) { 
			echo "<script>
				$init_script
			</script>";
		} else {
			echo "<script>
			document.addEventListener('DOMContentLoaded', function () {
				$init_script
		  	}, false);
			</script>";
		}
	}	
}