<?php

/**
 * Elementor Team Widget.
 *
 *
 * @since 1.0.0
 */
class Elementor_Section_Get_News_Widget extends \Elementor\Widget_Base
{

	/**
	 * Get widget name.
	 *
	 * Retrieve Team widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name()
	{
		return 'section-get-news';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Team widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title()
	{
		return __('Section News', 'elementor-custom-widgets');
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Team widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon()
	{
		return 'eicon-kit-details';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Team widget belongs to.
	 * Named aqb to be on top of the other categories
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories()
	{
		return ['aqb-widgets'];
	}

	/**
	 * Register widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function _register_controls()
	{
		$news_array = [];
		$news = get_posts([
			'post_type' => 'post',
			'post_status' => 'publish',
			'numberposts' => -1
			// 'order'    => 'ASC'
		]);

		foreach($news as $item) {
			$news_array += [
				$item->ID => $item->post_title
			];
		}

		$this->start_controls_section(
			'content_section',
			[
				'label' => __('Newsbeiträge', 'elementor-custom-widgets'),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'show_last_news',
			[
				'label' => __( 'Die letzten drei News anzeigen?', 'elementor-custom-widgets' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __( 'Ja', 'your-plugin' ),
				'label_off' => __( 'Nein', 'your-plugin' ),
				'return_value' => 'ja',
				'default' => 'ja',
			]
		);

		$this->add_control(
			'news_select',
			[
				'label' => __( 'Manuelle News Auswahl', 'elementor-custom-widgets' ),
				'type' => \Elementor\Controls_Manager::SELECT2,
				'multiple' => true,
				'options' => $news_array,
				'default' => [ 'title', 'description' ],
				'condition' => [ 'show_last_news!' => 'ja' ]
			]
		);

		$this->add_control(
			'note',
			[
				'label' => __( 'Hinweis', 'elementor-custom-widgets' ),
				'type' => \Elementor\Controls_Manager::RAW_HTML,
				'raw' => __( 'Bitte wählen Sie nur drei News aus.', 'elementor-custom-widgets' ),
				'content_classes' => 'your-class',
				'condition' => [ 'show_last_news!' => 'ja' ]
			]
		);

		$this->end_controls_section();

	}

	/**
	 * Render Team widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$recent_posts = wp_get_recent_posts(array(
			'post_type' => 'post',
			'numberposts' => 3,
			'post_status' => 'publish' 
		));

		echo '<div class="section-get-news">';
			echo '<div class="main-container">';
				echo '<h2>Aktuelles</h2>';
				echo '<div class="news-block-wrapper">';

					if ($settings['show_last_news'] == 'ja') {
						foreach( $recent_posts as $post_item ) {
							echo '<div class="news-item">';
								echo '<p class="news-title">' . $post_item['post_title'] . '</p>';
								echo '<p>' . apply_filters('the_excerpt', get_post_field('post_excerpt', $post_item['ID'])) . '</p>';
								echo '<a href="' . get_permalink($post_item['ID']) . '">';
									echo '<span class="read-further">Weiter lesen</span>';
								echo '</a>';
							echo '</div>';
						}
					} else {
						foreach ( $settings['news_select'] as $post_id ) {
							echo '<div class="news-item">';
								echo '<p class="news-title">' . get_the_title($post_id) . '</p>';
								echo '<p>' . apply_filters('the_excerpt', get_post_field('post_excerpt', $post_id)) . '</p>';
								echo '<a href="' . get_permalink($post_id) . '">';
									echo '<span class="read-further">Weiter lesen</span>';
								echo '</a>';
							echo '</div>';
						}
					}

				echo '</div>';
			echo '</div>';
		echo '</div>';	
	}
	

	protected function content_template() {
		$recent_posts = wp_get_recent_posts(array(
			'post_type' => 'post',
			'numberposts' => 3,
			'post_status' => 'publish' 
		));
		?>
		<div class="section-get-news">
			<div class="main-container">
				<h2>Aktuelles</h2>
				<div class="news-block-wrapper">
					<# if ( settings.show_last_news === 'ja' ) { #>
						<?php
						foreach( $recent_posts as $post_item ) {
							echo '<div class="news-item">';
								echo '<p class="news-title">' . $post_item['post_title'] . '</p>';
								echo '<p>' . apply_filters('the_excerpt', get_post_field('post_excerpt', $post_item['ID'])) . '</p>';
								echo '<a href="' . get_permalink($post_item['ID']) . '">';
									echo '<span class="read-further">Weiter lesen</span>';
								echo '</a>';
							echo '</div>';
						} ?>
					<# } #>

					<# if ( settings.show_last_news !== 'ja' ) { #>
						<# _.each( settings.news_select, function( post_id ) { #>
							<div class="news-item">
								<p class="news-title"><?php echo get_the_title(' . {{{post_id}}} . '); ?></p>
								<p><?php echo apply_filters('the_excerpt', get_post_field('post_excerpt', ' . {{{post_id}}} . ')); ?></p>
									<a href="<?php echo get_permalink(' . {{{post_id}}} . '); ?>">
									<span class="read-further">Weiter lesen</span>
								</a>
							</div>
						<# } ) #>
					<# } #>	
				</div>
			</div>
		</div>
		<?php
	}
}