<?php

/**
 * Elementor Team Widget.
 *
 *
 * @since 1.0.0
 */
class Elementor_Section_Slider_Intro_Widget extends \Elementor\Widget_Base
{

	/**
	 * Get widget name.
	 *
	 * Retrieve Team widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name()
	{
		return 'section-slider-intro';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Team widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title()
	{
		return __('Section Slider Intro', 'elementor-custom-widgets');
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Team widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon()
	{
		return 'eicon-slider-push';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Team widget belongs to.
	 * Named aqb to be on top of the other categories
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories()
	{
		return ['aqb-widgets'];
	}

	/**
	 * Register widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function _register_controls()
	{

		$this->start_controls_section(
			'content_section',
			[
				'label' => __('Inhalt', 'elementor-custom-widgets'),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);

		/**
		 * Start repater section
		 */

		$repeater = new \Elementor\Repeater();

		$repeater->add_control(
			'list_title',
			[
				'label' => __('Titel', 'elementor-custom-widgets'),
				'type' => \Elementor\Controls_Manager::TEXT,
				'placeholder' => __('Geben Sie bitte den Titel der Seite ein', 'elementor-custom-widgets'),
			]
		);

		$repeater->add_control(
			'content_image',
			[
				'label' => __('Bild wählen', 'elementor-custom-widgets'),
				'type' => \Elementor\Controls_Manager::MEDIA,
				//'default' => [
				//	'url' => \Elementor\Utils::get_placeholder_image_src(),
				//]
			]
		);

		$repeater->add_control(
			'section_content_left',
			[
				'label' => __('Inhaltstext links', 'elementor-custom-widgets'),
				'type' => \Elementor\Controls_Manager::TEXTAREA,
				//'default' => __( 'Bitte fügen Sie hier den gewünschten Text ein', 'elementor-custom-widgets' ),
				'placeholder' => __('Lorem Ipsum...', 'elementor-custom-widgets'),
			]
		);

		$repeater->add_control(
			'section_content_right',
			[
				'label' => __('Inhaltstext rechts', 'elementor-custom-widgets'),
				'type' => \Elementor\Controls_Manager::TEXTAREA,
				//'default' => __( 'Bitte fügen Sie hier den gewünschten Text ein', 'elementor-custom-widgets' ),
				'placeholder' => __('Lorem Ipsum...', 'elementor-custom-widgets'),
			]
		);

		$this->add_control(
			'list',
			[
				'label' => __('Slides', 'elementor-custom-widgets'),
				'type' => \Elementor\Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'default' => [
					[
						'list_title' => __('Slide #1', 'elementor-custom-widgets'),
						'list_content' => __('Item content. Click the edit button to change this text.', 'elementor-custom-widgets'),
					],
					[
						'list_title' => __('Slide #2', 'elementor-custom-widgets'),
						'list_content' => __('Item content. Click the edit button to change this text.', 'elementor-custom-widgets'),
					],
				],
				'title_field' => '{{{ list_title }}}',
			]
		);

		$this->add_control(
			'hr-divider',
			[
				'type' => \Elementor\Controls_Manager::DIVIDER,
			]
		);

		//$this->add_group_control(
		//	\Elementor\Group_Control_Background::get_type(),
		//	[
		//		'name' => 'background',
		//		'label' => __( 'Background', 'elementor-custom-widgets' ),
		//		'types' => [ 'classic' ],
		//		'selector' => '{{WRAPPER}} .wrapper',
		//	]
		//);

		//$this->add_control(
		//	'hr-divider2',
		//	[
		//		'type' => \Elementor\Controls_Manager::DIVIDER,
		//	]
		//);

		$this->add_control(
			'font_color',
			[
				'label' => __( 'Schriftfarbe', 'plugin-domain' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'scheme' => [
					'type' => \Elementor\Core\Schemes\Color::get_type(),
					'value' => \Elementor\Core\Schemes\Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .font' => 'color: {{VALUE}}',
				],
			]
		);

		$this->end_controls_section();
	}

	/**
	 * Render Team widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() 
	{
		$settings = $this->get_settings_for_display();
		$widget_id = $this->get_data()['id'];

		//$settings['background_color'] !== '' ? $bgColor = 'background-color:'.$settings['background_color'].';' : $bgColor = '';
		//!empty($settings['background_image']['url']) ? $bgImage = 'background-image:url('.$settings['background_image']['url'].');' : $bgImage = '';
		//$settings['background_position'] !== '' ? $bgPosition = 'background-position:'.$settings['background_position'].';' : $bgPosition = '';
		//$settings['background_repeat'] !== '' ? $bgRepeat = 'background-repeat:'.$settings['background_repeat'].';' : $bgRepeat = '';
		//$settings['background_size'] !== '' ? $bgSize = 'background-size:'.$settings['background_size'].';' : $bgSize = '';
		array_key_exists('font_color', $settings) ? $fontColor = $settings['font_color'] : $fontColor = '';
		
		$styleContainer = '';

		if (array_key_exists('font_color', $settings)) {
			$styleContainer = '
			<style>
				.section-slider-intro p, 
				.section-slider-intro a, 
				.section-slider-intro div {
					color:'.$fontColor.';
				}

				.section-bottom p:first-child,
				.section-bottom {
					border-color:'.$fontColor.';
				}
			</style>
			';
		}

		// Use the widget id to make a clear distinction between the individual sliders
		$init_script = "swiper_" . $widget_id . " = new Swiper('.swiper-container.widget_id_" . $widget_id . "', {
			loop: true,
		
			pagination: {
				el: '.swiper-pagination',
				type: 'fraction',
			},
		
			navigation: {
				nextEl: '.widget_id_" . $widget_id  . " .swiper-button-next',
				prevEl: '.widget_id_" . $widget_id  . " .swiper-button-prev',
			},
		});";

		echo '<div class="section-slider-intro">';
			echo '<div class="swiper-container widget_id_' . $widget_id . '">';
				echo '<div class="swiper-wrapper">';

					foreach ($settings['list'] as $element) 
					{
						echo '<div class="swiper-slide section-slider-2col" style="background-image:url(' . $element['content_image']['url'] . ');">';
							echo '<div class="main-container">';
								echo '<div class="section-top">';
									echo '<p class="big-font">' . $element['list_title'] . '</p>';
									//echo '<img src="' . $element['content_image']['url'] . '" alt="">';
									//echo '<div class="img-placeholder" style="background-image:url(' . $element['content_image']['url'] . ');"></div>';
								echo '</div>';
								echo '<div class="slider-control-wrapper">
										<div class="swiper-button-prev"></div>
										<div class="swiper-button-next"></div>
									</div>';
								echo '<div class="section-bottom">';
									echo '<p>' . $element['section_content_left'] . '</p>';
									echo '<p>' . $element['section_content_right'] . '</p>';
								echo '</div>';								
							echo '</div>';
						echo '</div>';
					}

				echo '</div>';
			echo '</div>';
		echo '</div>';
		echo $styleContainer;

		/**
		 * Check if the user is in live edit mode or not
		 * If not in live edit, load the js on doc ready otherwiese load it immediately
		 * Inline init script is used in case multiple sliders are on one page
		 */
		if( \Elementor\Plugin::$instance->editor->is_edit_mode() ) { 
			echo "<script>
				$init_script
			</script>";
		} else {
			echo "<script>
			document.addEventListener('DOMContentLoaded', function () {
				$init_script
		  	}, false);
			</script>";
		}
	}
}