<?php
/**
 * Enable svg in media upload
 */

function add_file_types_to_uploads($file_types)
{
    $new_filetypes = array();
    $new_filetypes['svg'] = 'image/svg';
    $file_types = array_merge($file_types, $new_filetypes);
    return $file_types;
}
add_action('upload_mimes', 'add_file_types_to_uploads');

// --------------------------------------------------------------- //

/**
 * increases the curl timeout and should resolve a handfull of problems. if it doesnt just delete it
 */
function bal_http_request_args($r)
{
    $r['timeout'] = 15;
    return $r;
}
add_filter('http_request_args', 'bal_http_request_args', 100, 1);

function bal_http_api_curl($handle) //called on line 1315

{
    curl_setopt($handle, CURLOPT_CONNECTTIMEOUT, 15);
    curl_setopt($handle, CURLOPT_TIMEOUT, 15);
}
add_action('http_api_curl', 'bal_http_api_curl', 100, 1);

// --------------------------------------------------------------- //

/**
 * add_ancestor_menu_classes:
 *
 * Go through each post and check if it has an ancestor, if so, add ancestor classes to the menu item
 * This is necessary if the post page differs from regular permalink structures
 *
 */
function add_ancestor_menu_classes($classes, $item)
{

    $post = get_post();
    $parent = get_post_parent($post);

    if (!$post) {
        return $classes;
    }

    if (!is_null($parent)) {
        $parent = get_post_parent($post)->ID;
    } else {
        return $classes;
    }

    do {
        if ($item->object_id == $parent && get_post_type() == 'post') {

            $classes[] = 'current_page_ancestor';
            $classes[] = 'current-page-ancestor';
            $classes[] = 'current-menu-ancestor';
        }

        if (!is_null(get_post_parent($parent))) {
            $parent = get_post_parent($parent)->ID;
        } else {
            $parent = 0;
        }

    } while ($parent !== 0);

    return $classes;
}
add_filter('nav_menu_css_class', 'add_ancestor_menu_classes', 10, 2);

// --------------------------------------------------------------- //


function contactform_dequeue_scripts() {
    $load_scripts = false;

    if( is_singular() ) {
        $post = get_post();

        if( has_shortcode($post->post_content, 'contact-form-7') ) {
            $load_scripts = true;       
        }
    }

    if( ! $load_scripts ) {
        wp_dequeue_script( 'contact-form-7' );
        wp_dequeue_script('google-recaptcha');
        wp_dequeue_style( 'contact-form-7' );
    }
}
add_action( 'wp_enqueue_scripts', 'contactform_dequeue_scripts', 99 );

// Disable cf7 auto p
add_filter('wpcf7_autop_or_not', '__return_false');


// Before send mail, replace optional fields with placeholder
function save_application_form($array)
{
    if (empty($array["unterfahrbarkeit"])) {
        $array["unterfahrbarkeit"] = 'Nichts ausgewählt';
    }

    if (empty($array["holzart"])) {
        $array["holzart"] = 'Nichts ausgewählt';
    }

    if (empty($array["upgrades"])) {
        $array["upgrades"] = '- Nichts ausgewählt';
    }

    if (empty($array["strasse"])) {
        $array["strasse"] = 'Keine Straße und Hausnummer hinterlegt';
    }

    if (empty($array["adresse"])) {
        $array["adresse"] = 'Kein Ort und PLZ hinterlegt';
    }

    if (empty($array["funktion"])) {
        $array["funktion"] = 'Keine Funktion / Abteilung hinterlegt';
    }

    if (empty($array["telefonnummer"])) {
        $array["telefonnummer"] = 'Keine Nummer hinterlegt';
    }

    if (empty($array["kommentar"])) {
        $array["kommentar"] = 'Kein Kommentar hinterlegt';
    }
    return $array;
}
add_filter( 'wpcf7_posted_data', 'save_application_form', 10, 1 );

// Split upgrades array for better readability in mail
add_filter( 'wpcf7_mail_tag_replaced', 
    function( $replaced, $submitted, $html, $mail_tag ) {
        if ( 'upgrades' == $mail_tag->field_name() ) {
            if ( is_array($submitted)) {
                $replaced = '';
                foreach ($submitted as $entry)  {
                    $replaced .= "- " . $entry . "\r\n";
                }   
            } 
        }
        
        if ( 'wunschprodukt' == $mail_tag->field_name() ) {
            if ( is_array($submitted)) {
                $replaced = '';
                foreach ($submitted as $entry)  {
                    $replaced .= "- " . $entry . "\r\n";
                }   
            } 
        }
        
        return $replaced;
    },
    10, 4
);




    
function wpcf7_do_something_else_with_the_data( $WPCF7_ContactForm ){

    // Submission object, that generated when the user click the submit button.
    $submission = WPCF7_Submission :: get_instance();
    $length_data = '';
    $counter = 2;
    if ( $submission ){
        $posted_data = $submission->get_posted_data();      
        if ( empty( $posted_data ) ){ return; }        
        
        foreach($posted_data as $key => $data) {            
            if (strpos($key, "laenge") !== false && $key != 'laenge') {
                $length_data .= "\r\nAbmessung Packgut Nr. ".$counter.":\r\n";
                $length_data .= "- Länge: ".$posted_data['laenge'.$counter]." mm\r\n";
                $length_data .= "- Breite: ".$posted_data['breite'.$counter]." mm\r\n";
                $length_data .= "- Höhe: ".$posted_data['hoehe'.$counter]." mm\r\n";
                $length_data .= "- Gewicht: ".$posted_data['gewicht'.$counter]." mm\r\n";
                $counter++;
            }
        }
        // Got e-mail text
        $mail = $WPCF7_ContactForm->prop( 'mail' );
        $mail2 = $WPCF7_ContactForm->prop( 'mail_2' );
        
        // Replace "[s2-name]" field inside e-mail text
        $new_mail = str_replace( '[weiterepackgueter]', $length_data, $mail );
        $new_mail2 = str_replace( '[weiterepackgueter]', $length_data, $mail2 );

        // Set
        $WPCF7_ContactForm->set_properties( array( 'mail' => $new_mail ) );
        $WPCF7_ContactForm->set_properties( array( 'mail_2' => $new_mail2 ) );
        
        return $WPCF7_ContactForm;
    }
}
add_action( 'wpcf7_before_send_mail', 'wpcf7_do_something_else_with_the_data', 90, 1 );

// --------------------------------------------------------------- //

/**
 * Hide backend pages for non-admins
 */

function hide_backend_menu_items()
{
    if (!current_user_can('manage_options')) { //current_user_can('editor')
        remove_menu_page('tools.php');
        remove_menu_page('edit-comments.php');
        remove_menu_page('profile.php');
        remove_menu_page('edit.php?post_type=elementor_library');
        remove_menu_page('wpcf7');
    }
}
add_action('admin_head', 'hide_backend_menu_items');

function admin_style() {
    wp_enqueue_style('admin-styles', WOKIT_PLUGIN_URL .'/assets/css/backend.css');
}
add_action('admin_enqueue_scripts', 'admin_style');

// ------------------------------------------------------------------------------


/**
 * Login Screen customization
 */

function custom_login_logo()
{
    ?>
	<style type="text/css">
		#login h1 a,
		.login h1 a {
			background-image: url(<?=WOKIT_PLUGIN_URL . '/assets/icons/zwei14_logo.svg';?>);
			height: 100px;
			width: 300px;
			background-size: 300px 100px;
			background-repeat: no-repeat;
			padding-bottom: 10px;
		}

		body.login {
			background: #000;
			background-image: url(<?=WOKIT_PLUGIN_URL . '/assets/images/login_background.jpg';?>);
			background-position: center;
			background-size: cover;
		}

		body #login {
			width: 320px;
			background: white;
			top: 50%;
			position: relative;
			transform: translateY(-50%);
			border-radius: 10px;
			padding: 2em;
		}

		body.login form {
			/*background: #333; */
			/*color: white;*/
			padding: 0;
			border: 0;
			border-bottom: 1px solid;
    		padding-bottom: 2em;
		}

		#login .button-primary {
			background: black;
			border-color: black;
		}

		/*div#login:after {
			content: "";
			background: rgba(255,255,255,0.4);
			width: 100%;
			height: 100%;
			display: block;
			position: absolute;
			left: 0;
			top: 0;
			z-index: -1;
		}*/
	</style>
	<?php
}
//add_action('login_enqueue_scripts', 'custom_login_logo');

//function custom_login_logo_url()
//{
//    return home_url();
//}
//add_filter('login_headerurl', 'custom_login_logo_url');
//
//function custom_login_logo_url_title()
//{
//    return get_bloginfo('name');
//}
//add_filter('login_headertext', 'custom_login_logo_url_title');
