<?php

/**
 * Check for current cache file, if not existing create one
 */
date_default_timezone_set('Europe/Berlin');

function xmlToArray(SimpleXMLElement $xml): array
{
    $parser = function (SimpleXMLElement $xml, array $collection = []) use (&$parser) {
        $nodes = $xml->children();
        $attributes = $xml->attributes();

        if (0 !== count($attributes)) {
            foreach ($attributes as $attrName => $attrValue) {
                $collection['attributes'][$attrName] = strval($attrValue);
            }
        }

        if (0 === $nodes->count()) {
            $collection['value'] = strval($xml);
            return $collection;
        }

        foreach ($nodes as $nodeName => $nodeValue) {
            if (count($nodeValue->xpath('../' . $nodeName)) < 2) {
                $collection[$nodeName] = $parser($nodeValue);
                continue;
            }

            $collection[$nodeName][] = $parser($nodeValue);
        }

        return $collection;
    };

    return [
        $xml->getName() => $parser($xml)
    ];
}

function download_page($path){
    $ch = curl_init();
    curl_setopt($ch, CURLOPT_URL,$path);
    curl_setopt($ch, CURLOPT_FAILONERROR,1);
    curl_setopt($ch, CURLOPT_FOLLOWLOCATION,1);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER,1);
    curl_setopt($ch, CURLOPT_TIMEOUT, 15);
    $retValue = curl_exec($ch);          
    curl_close($ch);
    return $retValue;
}

function createCacheFile() {
    $jopXMLPath = "https://k52916.coveto.de/public/xml/";
    $sXML = download_page($jopXMLPath);


    //$xmldata = simplexml_load_string($sXML);
  
    // Encode this xml data into json 
    // using json_encoe function
    //$jsondata = json_encode($xmldata);
    
    // Display json data
    //print_r($jsondata);
    


    $oXML = new SimpleXMLElement($sXML);
    
    $xmldata = xmlToArray($oXML);
    $result = Array();

    foreach($xmldata['jobs']['job'] as $singleJob){
        $tempArray = Array(
            'title' => $singleJob['title']['value'],
            'location' => $singleJob['city']['value'],
            'category' => $singleJob['category']['value'],
            'link' => $singleJob['link']['value'] 
        );
        array_push($result, $tempArray); 
    }
 
    //$includes = WOKIT_PLUGIN_DIR . '/includes';
    $filepath = fopen(dirname(__FILE__) . '/../job-cache/job-list_' . date("Y-m-d_H-i") . '.txt', 'w');
    if (flock($filepath,LOCK_EX)) {
        fwrite($filepath, json_encode($result));
        fflush($filepath);
        flock($filepath,LOCK_UN);
    } else {
        echo('File was blocked');
    }
    fclose($filepath);

    // Check existing cache files and delete old ones
    $counter = 0;
    $globFiles = glob(dirname(__FILE__) . "/../job-cache/*.txt");
    arsort($globFiles);
    foreach($globFiles as $key => $value) {
        if ($counter >= 10) {
            //var_dump($globFiles[$key]);
            unlink($globFiles[$key]);
        }
        $counter++;
    }

    //createView($result);
    return $filepath;
    
}

function getLastFile() {
    $globFiles = glob(dirname(__FILE__) . "/../job-cache/*.txt");
    $files = array_combine($globFiles, array_map("filemtime", $globFiles));
    arsort($files); 

    return key($files);
}

function checkCache () {      
    
    $last_modified_file = getLastFile();

    $fileTime = filemtime($last_modified_file);
    $now = time();
    
    // older than 30min
    if (is_null($last_modified_file)) {
        createCacheFile();
        $last_modified_file = getLastFile();
    } else if ($now - $fileTime > 1800) {
        createCacheFile();
        $last_modified_file = getLastFile();
    }

    return file_get_contents($last_modified_file);    
}

function createView($jobList, $auswahl) {
    
    $jobList = json_decode($jobList);
    
    
    $html = '<div class="main-container">';
    foreach($jobList as $singleJob){
        if ($auswahl == 'ausbildung' && $singleJob->category == 'Gewerblich') {
            continue;
        } else if ($auswahl == 'gewerblich' && $singleJob->category == 'Ausbildung') {
            continue;
        }

        $html .= '<div class="job-single">';
        $html .= '<a href="'.$singleJob->link.'" title="'.$singleJob->title.'" target="_blank">';
        
        $html .= '<p class="title">' . $singleJob->title . '</p>';
        $html .= '<p class="location">' . $singleJob->location . '</p>';
        $html .= '<p class="category">' . $singleJob->category . '</p>';
        $html .= '<p class="link">Detailansicht</p>';

        $html .= '</a>';
        $html .= '</div>';
    }
    $html .= '</div>';

    return $html;
}

function shortcode_function($attr){
    $args = shortcode_atts( array(     
        'auswahl' => 'alle'
    ), $attr );
    $currentJobsList = checkCache();
    return createView($currentJobsList, $args['auswahl']);
    //return createView(createCacheFile());
}
add_shortcode( 'job_list', 'shortcode_function' );