<?php

/**
 * Plugin Name: Tinymce Custom Options
 * Plugin URI: https://www.zwei14.de
 * Version: 1.0.0
 * Author: zwei14
 * Author URI: https://www.zwei14.de
 * Description: Customization for the WP TinyMCE Plugin
 */

class TinyMCE_Custom_Options_Class
{

    /**
     * Constructor. Load only if admin is logged in.
     */
    function __construct()
    {
        if (is_admin()) {
            add_action('init', array($this, 'setup_tinymce_plugin'));
        }
    }

    /**
     * Check if the current user can edit Posts or Pages, and is using the Visual Editor
     * If so, add some filters so we can register our plugin
     */
    function setup_tinymce_plugin()
    {

        // Check if the logged in WordPress User can edit Posts or Pages
        // If not, don't register our TinyMCE plugin

        if (!current_user_can('edit_posts') && !current_user_can('edit_pages')) {
            return;
        }

        // Check if the logged in WordPress User has the Visual Editor enabled
        // If not, don't register our TinyMCE plugin
        if (get_user_option('rich_editing') !== 'true') {
            return;
        }

        // Register our callback to the appropriate filter
        // Dont forget array(&$this, ...) otherwise the fuctions are not known

        add_filter('mce_buttons', array(&$this, 'change_buttons_first_row'), 100);
        add_filter('mce_buttons_2', array(&$this, 'change_buttons_second_row'), 200);
        add_filter('tiny_mce_before_init', array(&$this, 'change_style_formats'), 300);
        add_filter('mce_css', array(&$this, 'add_editor_styles'), 300);

        // Needs fix for elementor tinymce changes
        //add_filter( 'mce_buttons', array( &$this, 'remove_tinymce_buttons'), 40 );


        // Loop through all buttons for mce_buttons hook
        // echoes on the dashboard, for debugging purposes only!
        //add_filter( 'mce_buttons', array( &$this, 'loop_tinymce_buttons') );
        //add_filter( 'mce_buttons_2', array( &$this, 'loop_tinymce_buttons') );
    }

    function loop_tinymce_buttons($buttons)
    {
        echo '<strong>mce_buttons hook</strong><br/>';
        foreach ($buttons as $button) {
            echo $button . '</br>';
        }
    }

    function change_buttons_first_row($buttons)
    {
        // Just comment out the unwanted buttons or add them at the desired place.
        // !!! Does not function properly with elementor because it moves elements from first row to the second
        $toolbar1 = array(
            'styleselect',
            //'formatselect',
            'bold',
            'italic',
            'bullist',
            'numlist',
            'blockquote',
            'alignleft',
            'aligncenter',
            'alignright',
            'link',
            'unlink',
            'wp_more',
            'spellchecker',
            'fullscreen',
            'wp_add_media',
            'wp_adv',
        );
        $buttons = $toolbar1;
        return $buttons;
    }

    function change_buttons_second_row($buttons)
    {
        // Just comment out the unwanted buttons or add them at the desired place.
        // !!! Does not function properly with elementor because it moves elements from first row to the second
        $toolbar2 = array(
            //'strikethrough',
            //'hr',
            //'forecolor',
            'pastetext',
            'removeformat',
            'charmap',
            //'outdent',
            //'indent',
            'undo',
            'redo',
            //'wp_help',
        );

        $buttons = $toolbar2;
        return $buttons;
    }

    // Callback function to filter the MCE settings
    function change_style_formats($init_array)
    {
        // Define the style_formats array
        $style_formats = array(
            // Each array child is a format with it's own settings
            // Don't use 'classes' => 'example-class' cause it adds the class and is not removing it, if the user changes the format
            // Reset classes for formats without classes, otherwise old classes will remain
            array(
                'title' => 'Absatz',
                'block' => 'p',
                'attributes' => array(
                    'class' => ''
                ),
            ),
            array(
                'title' => 'H2 Objektiv',
                'block' => 'h2',
                'attributes' => array(
                    'class' => 'objektiv'
                ),
            ),
            array(
                'title' => 'H2 Amatic',
                'block' => 'h2',
                'attributes' => array(
                    'class' => 'amatic'
                ),

            ),
            array(
                'title' => 'H3 Objektiv',
                'block' => 'h3',
                'attributes' => array(
                    'class' => ''
                ),
            ),
            array(
                'title' => 'Link',
                'block' => 'span',
                'attributes' => array(
                    'class' => 'link'
                ),
            ),
            array(
                'title' => 'Absatz Amatic groß',
                'block' => 'span',
                'attributes' => array(
                    'class' => 'amatic'
                ),
            ),
            array(
                'title' => 'Absatz Amatic klein',
                'block' => 'span',
                'attributes' => array(
                    'class' => 'amatic small'
                ),
            ),
            array(
                'title' => 'Absatz Objektiv groß',
                'block' => 'span',
                'attributes' => array(
                    'class' => 'objektiv'
                ),
            ),
        );
        // Insert the array, JSON ENCODED, into 'style_formats'
        $init_array['style_formats'] = wp_json_encode($style_formats);

        return $init_array;
    }

    /**
     * Registers an editor stylesheet for the theme.
     */
    function add_editor_styles($mce_css)
    {
        if (!empty($mce_css))
            $mce_css .= ',';
        $mce_css .= WOKIT_PLUGIN_URL . '/assets/css/custom-editor-style.css';
        return $mce_css;
    }

    function remove_tinymce_buttons($buttons)
    {
        $remove = array('bold', 'alignleft');
        return array_diff($buttons, $remove);
    }
}

$tinymce_custom_options = new TinyMCE_Custom_Options_Class;
