<?php 
/* 
Template Name: Login-Page 
*/ 

?>
<!doctype html>
<html <?php language_attributes(); ?>>
<head>
	<meta charset="<?php bloginfo( 'charset' ); ?>">
	<meta name="viewport" content="width=device-width, initial-scale=1">
    <meta name="title" content="Login - <?php wp_title(); ?>">
    <title>Login - <?php wp_title(); ?></title>
	<link rel="profile" href="https://gmpg.org/xfn/11">

	<?php wp_head(); ?>
</head>
<body <?php body_class('login'); ?>>
<?php wp_body_open(); ?>
<div id="login">
    <h1>
        <a href="<?= get_home_url(); ?>"><?php wp_title(); ?></a>
    </h1>

    <?php

        /**
         * Finds and returns a matching error message for the given error code.
         *
         * @param string $error_code    The error code to look up.
         *
         * @return string               An error message.
         */
        function get_error_message( $error_code ) {
            switch ( $error_code ) {
                case 'empty_username':
                    return __( 'You need to enter a username or email address to login.', 'wokit-custom' );
        
                case 'empty_password':
                    return __( 'You need to enter a password to login.', 'wokit-custom' );
        
                case 'invalid_username':
                    return __( "We don't have any users with that name or email address. Maybe you used a different one when signing up?", 'wokit-custom' );
        
                case 'incorrect_password':
                    $err = __( "The password you entered wasn't quite right. <a href='%s'>Did you forget your password</a>?", 'wokit-custom' );
                    return sprintf( $err, wp_lostpassword_url() );
                    
                case 'invalid_email':
                    return __( 'There are no users registered with this name or email address.', 'wokit-custom' );

                case 'invalidcombo':
                    return __( 'There are no users registered with this name or email address.', 'wokit-custom' );

                // Reset password
                case 'expiredkey':
                case 'invalidkey':
                    return __( 'The password reset link you used is not valid anymore.', 'wokit-custom' );
                
                case 'password_reset_mismatch':
                    return __( "The two passwords you entered don't match.", 'wokit-custom' );
                    
                case 'password_reset_empty':
                    return __( "Sorry, we don't accept empty passwords.", 'wokit-custom' );

                default:
                    break;
            }
            
            return __( 'An unknown error occurred. Please try again later.', 'wokit-custom' );
        }

        // Error messages
        $errors = array();
        if ( isset( $_REQUEST['login'] ) && !isset( $_REQUEST['key'] )) {
            if ( isset( $_REQUEST['login'] )) {
                $error_codes = explode( ',', $_REQUEST['login'] );
            } 

            foreach ( $error_codes as $code ) {
                $errors []= get_error_message( $code );
            }
        }

        if (isset( $_REQUEST['lost_pass'] ) && isset( $_REQUEST['errors'] )) {
            $error_codes = explode( ',', $_REQUEST['errors'] );   
                    
            foreach ( $error_codes as $code ) {
                $errors []= get_error_message( $code );
            }
        }
        $attributes['errors'] = $errors;

        // Check if user just logged out
        $attributes['logged_out'] = isset( $_REQUEST['logged_out'] ) && $_REQUEST['logged_out'] == true;

        // Check if user lost password
        $attributes['lost_pass'] = isset( $_REQUEST['lost_pass'] ) && $_REQUEST['lost_pass'] == true;

        if ( ! is_user_logged_in() ) { // Display WordPress login form:
            $args = array(
                'redirect' => admin_url(), 
                'form_id' => 'loginform',
                'label_username' => __( 'Username or Email Address', 'wokit-custom' ),
                'label_password' => __( 'Password', 'wokit-custom'  ),
                'label_remember' => __( 'Remember Me', 'wokit-custom'  ),
                'label_log_in' => __( 'Log In', 'wokit-custom'  ),
                'remember' => true
            );
            
            // Show errors if there are any
            if ( count( $attributes['errors'] ) > 0 ) : ?>
                <p id="login_error">
                    <?php foreach ( $attributes['errors'] as $key => $error ) : ?>
                        <strong><?php _e('Error', 'wokit-custom'); ?>: </strong><?php echo $error; ?>
                    <?php 
                        if ($key !== array_key_last($attributes['errors'])) {
                            echo '<br>';
                        }
                    ?>
                    <?php endforeach; ?>
                </p>
            <?php endif;


            // Show logged out message if user just logged out
            if ( $attributes['logged_out'] ) : ?>
                <p class="login-info message">
                    <?php _e( 'You have signed out. Would you like to sign in again?', 'wokit-custom' ); ?>
                </p>
                <?php
                
            endif;

            // Check if the user just requested a new password 
            $attributes['lost_password_sent'] = isset( $_REQUEST['checkemail'] ) && $_REQUEST['checkemail'] == 'confirm';

            if ( $attributes['lost_password_sent'] ) : ?>
                <p class="login-info message">
                    <?php _e( 'Check your email for a link to reset your password.', 'wokit-custom' ); ?>
                </p>
            <?php endif;

            // Check if user just updated password
            $attributes['password_updated'] = isset( $_REQUEST['password'] ) && $_REQUEST['password'] == 'changed';
            
            if ( $attributes['password_updated'] ) : ?>
                <p class="login-info message">
                    <?php _e( 'Your password has been changed. You can sign in now.', 'wokit-custom' ); ?>
                </p>
            <?php endif;

            /**
             * Lost password
             */
            if ( $attributes['lost_pass'] && !$attributes['lost_password_sent'] && !isset( $_REQUEST['key'] )) : ?>
                <div id="password-lost-form" class="widecolumn">
                    <strong><?php _e( 'Forgot your password?', 'wokit-custom' ); ?></strong>
                    <br>
                    <p>
                        <?php
                            _e(
                                "Enter your email address or username and we'll send you a link you can use to pick a new password.",
                                'wokit-custom'
                            );
                        ?>
                    </p>

                    <form id="lostpasswordform" action="<?php echo wp_lostpassword_url(); ?>" method="post">
                        <p class="form-row">
                            <label for="user_login"><?php _e( 'Email or Username', 'wokit-custom' ); ?></label>
                            <input type="text" name="user_login" id="user_login">
                        </p>

                        <p class="lostpassword-submit">
                            <input type="submit" name="submit" class="lostpassword-button" value="<?php _e( 'Reset password', 'wokit-custom' ); ?>"/>
                        </p>
                    </form>
                </div>

                <p id="backtologin">
                    <a href="<?= home_url( WOKIT_BACKEND_URL ); ?>">← <?php _e('Back to', 'wokit-custom'); ?> Login</a>		
                </p>
                <?php
            endif;            

            if (! $attributes['lost_pass']) {
                wp_login_form( $args );
                ?>

                <a class="forgot-password" href="<?php echo wp_lostpassword_url(); ?>">
                    <?php _e( 'Forgot your password?', 'wokit-custom' ); ?>
                </a>
                <?php
            }

            // Check if the user clicked on the requested a new password link
            if(isset( $_REQUEST['login'])) {
                if ( is_user_logged_in() ) {
                    return __( 'You are already signed in.', 'wokit-custom' );
                } else {
                    if ( isset( $_REQUEST['login'] ) && isset( $_REQUEST['key'] ) ) {
                        $attributes['login'] = $_REQUEST['login'];
                        $attributes['key'] = $_REQUEST['key'];
            
                        // Error messages
                        $errors = array();
                        if ( isset( $_REQUEST['error'] ) ) {
                            $error_codes = explode( ',', $_REQUEST['error'] );
            
                            foreach ( $error_codes as $code ) {
                                $errors []= get_error_message( $code );
                            }
                        }
                        $attributes['errors'] = $errors;
            
                        ?>
                            <div id="password-reset-form" class="widecolumn">
                                <strong><?php _e( 'Pick a new password', 'wokit-custom' ); ?></strong>
                                <br>
                                <form name="resetpassform" id="resetpassform" action="<?php echo site_url( 'wp-login.php?action=resetpass' ); ?>" method="post" autocomplete="off">
                                    <input type="hidden" id="user_login" name="rp_login" value="<?php echo esc_attr( $attributes['login'] ); ?>" autocomplete="off" />
                                    <input type="hidden" name="rp_key" value="<?php echo esc_attr( $attributes['key'] ); ?>" />
                                    
                                    <?php if ( count( $attributes['errors'] ) > 0 ) : ?>
                                        <p id="login_error">
                                            <?php foreach ( $attributes['errors'] as $key => $error ) : ?>
                                                <strong><?php _e('Error', 'wokit-custom'); ?>: </strong><?php echo $error; ?>
                                            <?php 
                                                if ($key !== array_key_last($attributes['errors'])) {
                                                    echo '<br>';
                                                }
                                            ?>
                                            <?php endforeach; ?>
                                        </p>
                                    <?php endif; ?>

                                    <p>
                                        <label for="pass1"><?php _e( 'New password', 'wokit-custom' ) ?></label>
                                        <input type="password" name="pass1" id="pass1" class="input" size="20" value="" autocomplete="off" />
                                    </p>
                                    <p>
                                        <label for="pass2"><?php _e( 'Repeat new password', 'wokit-custom' ) ?></label>
                                        <input type="password" name="pass2" id="pass2" class="input" size="20" value="" autocomplete="off" />
                                    </p>
                                    
                                    <p class="description"><?php echo wp_get_password_hint(); ?></p>
                                    
                                    <p class="resetpass-submit">
                                        <input type="submit" name="submit" id="resetpass-button"
                                            class="button" value="<?php _e( 'Reset password', 'wokit-custom' ); ?>" />
                                    </p>
                                </form>
                            </div>
                            
                        <?php
                    } else {
                        ?>
                            <p id="backtoblog">
                                <a href="<?= home_url(); ?>">← <?php _e('Back to', 'wokit-custom'); ?> <?php echo get_bloginfo('name'); ?></a>		
                            </p>
                        <?php
                        return __( 'Invalid password reset link.', 'wokit-custom' );
                    }
                }
            }
            ?>
            
            <p id="backtoblog">
			    <a href="<?= home_url(); ?>">← <?php _e('Back to', 'wokit-custom'); ?> <?php echo get_bloginfo('name'); ?></a>		
            </p>

            <?php

        } else { // If logged in:
            wp_loginout( home_url() ); // Display "Log Out" link.
            echo " | ";
            wp_register('', ''); // Display "Site Admin" link.
        }

    ?>
</div>