<?php
class ElementorCustomSettings 
{
	/**
	 * Add action hooks and set main variables
	 */
	public function __construct()
	{
		$this->widget_manager = \Elementor\Plugin::instance()->widgets_manager;
		$this->elements_manager = \Elementor\Plugin::instance()->elements_manager;
		$this->options = get_option('custom-widget-options');

		add_action('admin_init', [$this, 'page_init'], 100);
		add_action('admin_menu', [$this, 'my_admin_menu'], 800);
		add_action('elementor/widgets/widgets_registered', [$this, 'disable_widgets'], 50);
	}

	/**
	 * Get all registered widget types and save them for later
	 * as soon as we unregister unwanted widgets, get_widget_types() is not containing them anymore
	 */
	public function create_widget_list()
	{
		$temp = $this->widget_manager;
		foreach (array_keys($temp->get_widget_types()) as $widget) 
		{

			if ($temp->get_widget_types($widget)->get_title() == '') 
			{
				continue;
			}
			
			$this->widget_list[] = [
				'id' => $widget,
				'title' => $temp->get_widget_types($widget)->get_title(),
				'icon' => $temp->get_widget_types($widget)->get_icon(),
				'category' => $temp->get_widget_types($widget)->get_categories()[0]
			];
		}

		return $this->widget_list;
	}

	// Creates a new page
	public function my_admin_menu()
	{
		$backend_options = get_option('custom-setting-options');
		$widget_options = get_option('custom-widget-options');

		/**
		 * Add submenupage for selecting widgets
		 */
		$submenu = add_submenu_page(
			'elementor',
			__('Widget Optionen', 'elementor-custom-widget-options'),
			__('Widget Optionen', 'elementor-custom-widget-options'),
			'manage_options',
			'elementor-custom-widget-options',
			array($this, 'create_admin_page'),
			200
		);

		/**
		 * Register custom admin styles and scripts
		 */
		add_action('admin_print_styles-' . $submenu, [$this, 'admin_custom_css']);
		add_action('admin_print_scripts-' . $submenu, [$this, 'admin_custom_js']);


		/**
		 * Remove Pro Elements placeholder from Editor
		 */
		if (isset($widget_options['option_name_pro-elements']) && $widget_options['option_name_pro-elements'] == 'inactive') {
			add_action('elementor/editor/after_enqueue_scripts', [&$this, 'enqueue_editor_assets']);
		}

		/**
		 * Remove all Pro Elements from Backend Menu
		 */
		if (isset($backend_options['remove_pro_elements_backend']) && $backend_options['remove_pro_elements_backend'] == 'hide') {
			remove_submenu_page('elementor', 'go_elementor_pro');
		}

		if (isset($backend_options['remove_icons_backend']) && $backend_options['remove_icons_backend'] == 'hide') {
			remove_submenu_page('elementor', 'elementor_custom_icons');
		}

		if (isset($backend_options['remove_fonts_backend']) && $backend_options['remove_fonts_backend'] == 'hide') {
			remove_submenu_page('elementor', 'elementor_custom_fonts');
		}

		if (isset($backend_options['remove_submissions_backend']) && $backend_options['remove_submissions_backend'] == 'hide') {
			remove_submenu_page('elementor', 'e-form-submissions');
		}

		if (isset($backend_options['remove_popup_backend']) && $backend_options['remove_popup_backend'] == 'hide') {
			remove_submenu_page('edit.php?post_type=elementor_library', 'popup_templates');
		}
	}

	public function enqueue_editor_assets()
	{
		$path = WOKIT_PLUGIN_DIR . '/assets/css/elementor-deactivate-modules-style.css';
		wp_enqueue_style('elementor-deactivate-modules-style', plugins_url('../assets/css/elementor-deactivate-modules-style.css', __FILE__), '', filemtime($path));
	}

	function admin_custom_css()
	{
		$path = WOKIT_PLUGIN_DIR . '/assets/css/elementor-custom-settings-page.css';
		wp_enqueue_style('elementor-custom-settings-page', plugins_url('../assets/css/elementor-custom-settings-page.css', __FILE__), '', filemtime($path));
	}

	function admin_custom_js()
	{
		$path = WOKIT_PLUGIN_DIR . '/assets/js/elementor-custom-settings-page.js';
		wp_enqueue_script('elementor-custom-settings-page', plugins_url('../assets/js/elementor-custom-settings-page.js', __FILE__), '', filemtime($path), true);
	}

	public function disable_widgets()
	{
		$this->widget_list = $this->create_widget_list();

		if ($this->options) {
			foreach ($this->options as $key => $value) {
				$current_widget = explode("option_name_", $key)[1];
	
				if ($value == 'inactive') {
					$this->widget_manager->unregister_widget_type($current_widget);
				}
			}
		}		
	}


	/**
	 * Options page callback
	 */

	public function create_admin_page()
	{
		// Set class property
		if (isset($_REQUEST['settings-updated'])) {
			echo '<div id="message" class="updated fade"><p><strong>Die Einstellungen wurden erfolgreich gespeichert.</strong></p></div>';
		}

		//$this->options = get_option( 'custom-widget-options' );
	?>

		<div class="wrap card" style="max-width:100%;">
			<h2>Widget Optionen</h2>
			<!--<div class="notice notice-info"><p>Bitte verwenden Sie ...</p></div>-->
			<?php $active_tab = isset($_GET['tab']) ? $_GET['tab'] : 'widget_section'; ?>

			<h2 class="nav-tab-wrapper">
				<a href="?page=elementor-custom-widget-options&tab=widget_section" class="nav-tab <?php echo $active_tab == 'widget_section' ? 'nav-tab-active' : ''; ?>">Widgets</a>
				<a href="?page=elementor-custom-widget-options&tab=settings_section" class="nav-tab <?php echo $active_tab == 'settings_section' ? 'nav-tab-active' : ''; ?>">Settings</a>
			</h2>


			<form method="post" action="options.php" class="<?= $active_tab ?>">

				<?php
				if ($active_tab == 'widget_section') {
					submit_button();
					settings_fields('custom-widget-group');
				?>
					
				<?php
					do_settings_sections('show_widget_section_page');
					submit_button();
				} else if ($active_tab == 'settings_section') {
					submit_button();
					settings_fields('custom-setting-group');
					do_settings_sections('show_settings_section_page');
					submit_button();
				}
				?>
			</form>
		</div>
		<?php
	}


	/**
	 * Register and add settings
	 */
	public function page_init()
	{
		register_setting(
			'custom-widget-group', // Option group
			'custom-widget-options', // Option name
			array($this, 'sanitize') // Sanitize
		);

		register_setting(
			'custom-setting-group', // Option group
			'custom-setting-options', // Option name
			array($this, 'sanitize') // Sanitize
		);

		//----------------------------------------

		add_settings_section(
			'show_widget_section', // ID
			'', // Title
			array($this, 'show_widget_section_callback'), // Callback
			'show_widget_section_page' // Page
		);

		$elements_manager = \Elementor\Plugin::instance()->elements_manager;
		$widget_manager = \Elementor\Plugin::instance()->widgets_manager;

		foreach ($elements_manager->get_categories() as $key => $category) {
			if (array_key_exists('active', $category) && $category['active'] == false && $category['title'] != 'WordPress' || $category['title'] == 'Pojo Themes') {
				continue;
			}
			add_settings_field(
				'widget_type_' . $key, // ID
				$category['title'], // Title 
				array($this, 'widget_callback'), // Callback
				'show_widget_section_page', // Page
				'show_widget_section', // Section           
				array('cat_type' => $key, 'cat_title' => $category['title'], 'widget_manager' => $widget_manager)
			);
		}

		add_settings_section(
			'show_settings_section', // ID
			'', // Title
			array($this, 'show_settings_section_callback'), // Callback
			'show_settings_section_page' // Page
		);

		add_settings_field(
			'custom-setting', // ID
			'Backend Seiten', // Title 
			array($this, 'settings_callback'), // Callback
			'show_settings_section_page', // Page
			'show_settings_section', // Section           
			//array('cat_type' => $key, 'cat_title' => $category['title'], 'widget_manager' => $widget_manager)
		);
	}

	function show_widget_section_callback($arg)
	{
		return;
	}

	function show_settings_section_callback($arg)
	{
		return;
	}

	/**
	 * Sanitize each setting field as needed
	 * @param array $input Contains all settings fields as array keys
	 */

	public function sanitize($input)
	{
		return array_map('wp_filter_nohtml_kses', (array)$input);
	}

	//---------------------------------------- 

	public function widget_callback($args)
	{
		$options = get_option('custom-widget-options');
		$category_type = $args['cat_type'];
		$widget_manager = $args['widget_manager']->get_widget_types();
		//$counter = 0;

		foreach ($this->widget_list as $item) {
			if ($category_type == $item['category']) : ?>

				<div class="widget-item <?= !isset($options['option_name_' . $item['id']]) ? 'active' : $options['option_name_' . $item['id']] ?>">
					<p><?= $item['title'] ?></p>
					<p class="icon"><i class="<?= $item['icon'] ?>" aria-hidden="true"></i></p>
					<input name="custom-widget-options[option_name_<?= $item['id'] ?>]" type="radio" value="active" <?php checked('active', !isset($options['option_name_' . $item['id']]) ? 'active' : $options['option_name_' . $item['id']]); ?> />
					<input name="custom-widget-options[option_name_<?= $item['id'] ?>]" type="radio" value="inactive" <?php checked('inactive', !isset($options['option_name_' . $item['id']]) ? '' : $options['option_name_' . $item['id']]); ?> />
				</div>
			<?php endif;
		}

		if ($category_type == 'pro-elements') : ?>
			<div class="widget-item <?= !isset($options['option_name_pro-elements']) ? 'active' : $options['option_name_pro-elements'] ?>">
				<p>Pro Elements</p>
				<p class="icon"><i class="eicon-pro-icon" aria-hidden="true"></i></p>
				<input name="custom-widget-options[option_name_pro-elements]" type="radio" value="active" <?php checked('active', !isset($options['option_name_pro-elements']) ? 'active' : $options['option_name_pro-elements']); ?> />
				<input name="custom-widget-options[option_name_pro-elements]" type="radio" value="inactive" <?php checked('inactive', !isset($options['option_name_pro-elements']) ? '' : $options['option_name_pro-elements']); ?> />
			</div>
		<?php endif;
	}

	function settings_callback($args)
	{
		$options = get_option('custom-setting-options');
		$iconBaseSrc = WOKIT_PLUGIN_URL . '/assets/icons/icon-eye-closed.svg';
		$proBackend = !isset($options['remove_pro_elements_backend']) ? 'show' : $options['remove_pro_elements_backend'];
		$iconBackend = !isset($options['remove_icons_backend']) ? 'show' : $options['remove_icons_backend'];
		$fontsBackend = !isset($options['remove_fonts_backend']) ? 'show' : $options['remove_fonts_backend'];
		$submissionBackend = !isset($options['remove_submissions_backend']) ? 'show' : $options['remove_submissions_backend'];
		$popupBackend = !isset($options['remove_popup_backend']) ? 'show' : $options['remove_popup_backend'];

		?>
		<div class="setting-item <?= $proBackend ?>">
			<p>Pro Werbung</p>
			<p class="status"><?= $proBackend == 'show' ? 'eingeblendet' : 'ausgeblendet'; ?></p>
			<p class="icon"><img src="<?= $iconBaseSrc ?>" alt="Fontawesome Eye"></p>
			<div class="non-visible">
				<input name="custom-setting-options[remove_pro_elements_backend]" type="radio" value="show" <?php checked('show', !isset($options['remove_pro_elements_backend']) ? 'show' : $options['remove_pro_elements_backend']); ?> />
				<input name="custom-setting-options[remove_pro_elements_backend]" type="radio" value="hide" <?php checked('hide', !isset($options['remove_pro_elements_backend']) ? '' : $options['remove_pro_elements_backend']); ?> />
			</div>
		</div>

		<div class="setting-item <?= $iconBackend ?>">
			<p>Custom Icons</p>
			<p class="status"><?= $iconBackend == 'show' ? 'eingeblendet' : 'ausgeblendet'; ?></p>
			<p class="icon"><img src="<?= $iconBaseSrc ?>" alt="Fontawesome Eye"></p>
			<div class="non-visible">
				<input name="custom-setting-options[remove_icons_backend]" type="radio" value="show" <?php checked('show', !isset($options['remove_icons_backend']) ? 'show' : $options['remove_icons_backend']); ?> />
				<input name="custom-setting-options[remove_icons_backend]" type="radio" value="hide" <?php checked('hide', !isset($options['remove_icons_backend']) ? '' : $options['remove_icons_backend']); ?> />
			</div>
		</div>

		<div class="setting-item <?= $fontsBackend ?>">
			<p>Custom Fonts</p>
			<p class="status"><?= $fontsBackend == 'show' ? 'eingeblendet' : 'ausgeblendet'; ?></p>
			<p class="icon"><img src="<?= $iconBaseSrc ?>" alt="Fontawesome Eye"></p>
			<div class="non-visible">
				<input name="custom-setting-options[remove_fonts_backend]" type="radio" value="show" <?php checked('show', !isset($options['remove_fonts_backend']) ? 'show' : $options['remove_fonts_backend']); ?> />
				<input name="custom-setting-options[remove_fonts_backend]" type="radio" value="hide" <?php checked('hide', !isset($options['remove_fonts_backend']) ? '' : $options['remove_fonts_backend']); ?> />
			</div>
		</div>

		<div class="setting-item <?= $submissionBackend ?>">
			<p>Submissions</p>
			<p class="status"><?= $submissionBackend == 'show' ? 'eingeblendet' : 'ausgeblendet'; ?></p>
			<p class="icon"><img src="<?= $iconBaseSrc ?>" alt="Fontawesome Eye"></p>
			<div class="non-visible">
				<input name="custom-setting-options[remove_submissions_backend]" type="radio" value="show" <?php checked('show', !isset($options['remove_submissions_backend']) ? 'show' : $options['remove_submissions_backend']); ?> />
				<input name="custom-setting-options[remove_submissions_backend]" type="radio" value="hide" <?php checked('hide', !isset($options['remove_submissions_backend']) ? '' : $options['remove_submissions_backend']); ?> />
			</div>
		</div>

		<div class="setting-item <?= $popupBackend ?>">
			<p>Pop-Up Templates</p>
			<p class="status"><?= $popupBackend == 'show' ? 'eingeblendet' : 'ausgeblendet'; ?></p>
			<p class="icon"><img src="<?= $iconBaseSrc ?>" alt="Fontawesome Eye"></p>
			<div class="non-visible">
				<input name="custom-setting-options[remove_popup_backend]" type="radio" value="show" <?php checked('show', !isset($options['remove_popup_backend']) ? 'show' : $options['remove_popup_backend']); ?> />
				<input name="custom-setting-options[remove_popup_backend]" type="radio" value="hide" <?php checked('hide', !isset($options['remove_popup_backend']) ? '' : $options['remove_popup_backend']); ?> />
			</div>
		</div>
		<?php
	}
}

if (is_admin()) {
	$my_settings_page = new ElementorCustomSettings();
}